@@ -1,5 +1,5 @@
 import os
 import sys
 sys.path.insert(0, os.path.abspath(os.path.join(os.path.dirname(__file__), '..')))
-    
-from instagram_scraper.instagram import Instagram
+	
+from igramscraper.instagram import Instagram
\ No newline at end of file
