@@ -1,6 +1,7 @@
 from context import Instagram # pylint: disable=no-name-in-module
 
-instagram = Instagram.with_credentials('', '', 'pathtocache')
+instagram = Instagram()
+instagram.with_credentials('', '', 'pathtocache')
 instagram.login()
 
 instagram.follow('user_id')
