@@ -1,7 +1,7 @@
 from context import Instagram # pylint: disable=no-name-in-module
 
 instagram = Instagram()
-instagram = Instagram.with_credentials('username', 'password', 'path/to/cache/folder')
+instagram.with_credentials('username', 'password', 'path/to/cache/folder')
 instagram.login()
 
 medias = instagram.get_current_top_medias_by_location_id('1')
