@@ -1,10 +1,10 @@
-from context import Instagram # pylint: disable=no-name-in-module
+from igramscraper.instagram import Instagram
 
 # If account is public you can query Instagram without auth
 instagram = Instagram()
 
 # If account is private and you subscribed to it, first login
-# instagram = Instagram.with_credentials('username', 'password', 'cachepath')
+# instagram.with_credentials('username', 'password', 'cachepath')
 # instagram.login()
 
 media = instagram.get_media_by_id('1270593720437182847')
