@@ -1,8 +1,7 @@
-#TODO does not work currently instagram changed api
-
 from context import Instagram # pylint: disable=no-name-in-module
 
-instagram = Instagram.with_credentials('username', 'password', 'path/to/cache/folder')
+instagram = Instagram()
+instagram.with_credentials('', '', '/pathtocache')
 instagram.login()
 
 # echo "Number of comments: {$medias[0]->get_comments_count()}\n";
@@ -10,10 +9,10 @@ instagram.login()
 # or by id
 comments = instagram.get_media_comments_by_id('1130748710921700586', 10000)
 
-# Let's take first comment in array and explore available fields
+for comment in comments['comments']:
+    print(comment.text)
+    print(comment.owner)
 
-comment = comments[0]
-print(vars(comment))
 
 # You can start loading comments from specific comment by providing comment id
 # comments = instagram.getMediaCommentsByCode('BG3Iz-No1IZ', 200, comment.identifier)
\ No newline at end of file
